Module environment

Module environment 

Environment handlers

This module contains handlers for various environments. Generally a handler is characterized by implementing the IsEnvironment trait and integrating with the current function.

Especially IsEnvironment::execute function isn’t usually trivial to implement, since the precise commands to run (and wrap) depend on the current and target execution environment.

Modules

container
Container Environment Handler
distrobox
Distrobox Environment Handler
host
Host Environment Handler
toolbx
Toolbx Environment Handler

Structs

SerializationError
invalid environment specification ‘{raw}’

Enums

Environment
All the execution environments known to the applicaiton.
Error
Environment execution error.
ExecutionError
Common errors from command execution.
StartError
Error from starting up an environment.

Traits

IsEnvironment
Trait for usable environments.

Functions

current
Return the current execution environment.
read_env_vars
Preserve the users environments.