Module container

Module container 

Container Environment Handler

This runs ad-hoc containers from local container storage or a remote container registry if configured.

This is not currently implemented but planned for later on. If you have a need for this feature, please let us know!

Functions

detect
Detect if the current environment is a container.
run
Run a command in a container environment.