pub enum CurrentToolbxError {
Environment {
env_file: String,
source: Error,
},
NotAToolbx,
Name(String),
}Expand description
Errors related to distrobox as environment that launched cnf.
Variants
Environment
cannot read toolbx info from environment file ‘{env_file}’: {source}
Fields
NotAToolbx
program currently isn’t run from a toolbx
Name(String)
failed to read toolbx name from environment file ‘{0}’