pub struct Toolbx { /* private fields */ }Expand description
Environment for a Toolbx container
Implementations
Sourceimpl Toolbx
impl Toolbx
Sourcepub fn new(name: Option<String>) -> Result<Toolbx, NewToolbxError>
pub fn new(name: Option<String>) -> Result<Toolbx, NewToolbxError>
Spawn a Toolbx container with a given name.
Checks if the toolbx container exists and starts it, if necessary. If None is given as
name, will try to determine the default toolbx name and start that instead. Returns an
error if unsuccessful.
Sourcepub fn start(&self) -> Result<(), StartToolbxError>
pub fn start(&self) -> Result<(), StartToolbxError>
Starts a given toolbx container.
This function is automatically called by new() above and should only ever be called when
creating a Toolbx object without using the constructor. This is currently the case when
executing aliases in cnf, as the Toolbx instance is deserialized from the config in
that case.
Sourcepub fn current() -> Result<Toolbx, CurrentToolbxError>
pub fn current() -> Result<Toolbx, CurrentToolbxError>
Get the Toolbx container currently executing CNF.
Will return an error if the current execution environment isn’t Toolbx.
Sourcepub fn default_name() -> Result<String, DefaultToolbxError>
pub fn default_name() -> Result<String, DefaultToolbxError>
Get the name of the default toolbx to lookup/execute commands in.
The default toolbx container name is assembled from the contents of /etc/os-release.