Helpers for working with command lines
Provides CommandLine and the accompanying macro cmd!, which abstract the trouble of
assembling command lines for Environments. Most importantly,
CommandLine offers an Environment-agnostic way of requesting
privileges for command execution. This is useful when interacting with system package managers,
for example, which often require root privileges for installation or updating caches.
See CommandLine::privileged for more information.
Macros
- cmd
- Conveniently create
CommandLines.
Structs
- Command
Line - Convenient container for commandlines to execute in an
crate::env::Environment.