pub struct OutputMatcher<'a> { /* private fields */ }Expand description
Match substrings in command output.
Due to the problems described in crate::env::ExecutionError::NonZero, the output of
crate::env::Environment::output_of() doesn’t reliably catch the contents of stderr
in the actual stderr variable. For Providers, this means
that when searching for error strings in command output, both stdout and stderr must be
checked for occurences of the pattern. This struct removes a lof of the resulting boilerplate
code for first converting a Vec<u8> into something string-like, and then matching stdout
and stderr against a pattern.
Implementations
Sourceimpl<'a> OutputMatcher<'a>
impl<'a> OutputMatcher<'a>
Sourcepub fn new(output: &'a Output) -> Self
pub fn new(output: &'a Output) -> Self
Create a new instance of OutputMatcher for the given command output.
Sourcepub fn starts_with(&self, pat: &str) -> bool
pub fn starts_with(&self, pat: &str) -> bool
Returns true if either stdout or stderr starts with pat.
Sourcepub fn contains(&self, pat: &str) -> bool
pub fn contains(&self, pat: &str) -> bool
Returns true if either stdout or stderr contains pat.