Module host

Module host 

Host Environment Handler

This module handles command-not-found errors that occur while executing on the host OS. Currently this means that the command is forwarded to a Toolbx container of choice, preferrably one specified in the configuration file or the default one otherwise.

Structs

Host
Environment of the native host operating system.